==> ns-sso-client-2.0.0-20250911.073838-42-sources.jar: com/geoway/sso/client/constant/UisConstant.java <==
package com.geoway.sso.client.constant;

/**
 * @author ALMJ
 * @desc Oauth2 规范API相关常量
 */
public class UisConstant {

    public static final String ID = "id";

    public static final String USER_ID = "userId";

    public static final String USER_SYS = "userSys";

    public static final String FilterParam = "filterParam";
    public static final String SYSTEMKEY="systemKey";
    public static final String KEY="key";

    public static final String PageParam = "page";
    public static final String SizeParam = "size";


    public static final String RoleId = "roleId";

    public static final String PID = "pid";

    public static final String QUERY_USERDETAIL_URL = "/user/findOne";

    public static final String QUERY_CURRENT_USERDETAIL_URL = "/user/queryUserInfo";
    public static final String QUERY_USERSYSTEMS_URL = "/user/getUserSystems";

    public static final String QUERY_USER_SEVERROUTE= "/rest/user/serverRoutes";

    public static final String MODIFY_USER_URL = "/user/update";

    public static final String CHANGEPWD_USER_URL = "/user/changePwd";

    public static final String QUERY_USERLIST_URL = "/user/queryList";

    public static final String QUERY_USERONLINE_URL = "/user/queryCount";

    public static final String QUERY_CURRENT_USERTEL_URL = "/user/getCurUserRealTel";
    /**
     * 校验当前用户是否需要重置密码
     */
    public static final String VALID_USE_ISNEEDRESETPASSWORD = "/user/validSecure";

    public static final String QUERY_ORGTREE_URL = "/organization/queryTree";

    public static final String QUERY_ORGLIST_URL = "/organization/queryList";
    public static final String QUERY_ORGRELUSERS_URL = "/organization/users";

    public static final String QUERY_ORGDETAIL_URL = "/organization/findOne";

    public static final String QUERY_ROLETREE_URL="/role/queryTree";

    public static final String QUERY_ROLELIST_URL="/role/list";

    public static final String QUERY_ROLEUSER_URL="/role/users";

    public static final String QUERY_MENUSUBFUNCTION_URL="/system/querySubFunctions";
    public static final String QUERY_MENUSUBFUNCTIONTREE_URL="/system/querySubFunctionTree";
    public static final String Query_ROLEPAGE_URL="/role/queryPage";

    public static final String Query_TENANTPAGE_URL="/tenant/queryPage";
    public static final String Query_SYSTEMINFO_URL="/system/queryInfoByKey";
    public static final String REDIS_TOKEN_USERROUTE="UserRoute:Routes:";



}

==> ns-sso-client-2.0.0-20251120.005122-67-sources.jar: com/geoway/sso/client/constant/UisConstant.java <==
package com.geoway.sso.client.constant;

/**
 * @author ALMJ
 * @desc Oauth2 规范API相关常量
 */
public class UisConstant {

    public static final String ID = "id";

    public static final String USER_ID = "userId";

    public static final String USER_SYS = "userSys";

    public static final String FilterParam = "filterParam";
    public static final String SYSTEMKEY="systemKey";
    public static final String KEY="key";

    public static final String PageParam = "page";
    public static final String SizeParam = "size";


    public static final String RoleId = "roleId";

    public static final String PID = "pid";

    public static final String QUERY_USERDETAIL_URL = "/user/findOne";

    public static final String QUERY_CURRENT_USERDETAIL_URL = "/user/queryUserInfo";
    public static final String QUERY_USERSYSTEMS_URL = "/user/getUserSystems";

    public static final String QUERY_USER_SEVERROUTE= "/rest/user/serverRoutes";

    public static final String MODIFY_USER_URL = "/user/update";

    public static final String CHANGEPWD_USER_URL = "/user/changePwd";

    public static final String MODIFYPWD_USER_URL = "/user/modifyPassword";

    public static final String QUERY_USERLIST_URL = "/user/queryList";

    public static final String QUERY_USERONLINE_URL = "/user/queryCount";

    public static final String QUERY_CURRENT_USERTEL_URL = "/user/getCurUserRealTel";
    /**
     * 校验当前用户是否需要重置密码
     */
    public static final String VALID_USE_ISNEEDRESETPASSWORD = "/user/validSecure";

    public static final String QUERY_ORGTREE_URL = "/organization/queryTree";

    public static final String QUERY_ORGLIST_URL = "/organization/queryList";
    public static final String QUERY_ORGRELUSERS_URL = "/organization/users";

    public static final String QUERY_ORGDETAIL_URL = "/organization/findOne";

    public static final String QUERY_ROLETREE_URL="/role/queryTree";

    public static final String QUERY_ROLELIST_URL="/role/list";

    public static final String QUERY_ROLEUSER_URL="/role/users";

    public static final String QUERY_MENUSUBFUNCTION_URL="/system/querySubFunctions";
    public static final String QUERY_MENUSUBFUNCTIONTREE_URL="/system/querySubFunctionTree";
    public static final String Query_ROLEPAGE_URL="/role/queryPage";

    public static final String Query_TENANTPAGE_URL="/tenant/queryPage";
    public static final String Query_SYSTEMINFO_URL="/system/queryInfoByKey";
    public static final String SAVE_RESULT_URL = "/system/saveSystemConsult";
    public static final String REDIS_TOKEN_USERROUTE="UserRoute:Routes:";



}
